@@ -3,9 +3,9 @@ from typing import Dict, List
 import jupyter_server.serverapp
 from jupyter_server.utils import url_path_join
 
-from .ydoc import YDocWebSocketHandler
+from .ydoc import YDocRoomIdHandler, YDocWebSocketHandler
 
-__version__ = "0.1.13"
+__version__ = "0.1.14"
 
 
 def _jupyter_server_extension_points() -> List[Dict[str, str]]:
@@ -15,8 +15,15 @@ def _jupyter_server_extension_points() -> List[Dict[str, str]]:
 def _load_jupyter_server_extension(serverapp: jupyter_server.serverapp.ServerApp) -> None:
     web_app = serverapp.web_app
     host_pattern = ".*$"
-    route_pattern = url_path_join(web_app.settings["base_url"], r"/api/yjs/(.*)")
-    web_app.add_handlers(host_pattern, [(route_pattern, YDocWebSocketHandler)])
+    yid_route_pattern = url_path_join(web_app.settings["base_url"], r"/api/yjs/roomid/(.*)")
+    yws_route_pattern = url_path_join(web_app.settings["base_url"], r"/api/yjs/(.*)")
+    web_app.add_handlers(
+        host_pattern,
+        [
+            (yid_route_pattern, YDocRoomIdHandler),
+            (yws_route_pattern, YDocWebSocketHandler),
+        ],
+    )
 
 
 # Backward compatibility for classic notebook based start-up (e.g. Binder)
